Crate liquid_cache_datafusion

Crate liquid_cache_datafusion 

liquid-cache-datafusion

Parquet reader with liquid array caching and optimized data formats.

Re-exports

pub use cache::LiquidCacheParquet;
pub use cache::LiquidCacheParquetRef;
pub use liquid_cache as storage;
pub use liquid_cache_common as common;

Modules

cache
This module contains the cache implementation for the Parquet reader.
optimizers
Optimizers for the Parquet module

Structs

FilterCandidateBuilder
Helper to build a FilterCandidate.
LiquidParquetSource
The data source for LiquidCache
LiquidPredicate
A “compiled” predicate passed to ParquetRecordBatchStream to perform row-level filtering during parquet decoding.
LiquidRowFilter
A row filter that can be used to filter rows from a parquet file.
VariantGetUdf
UDF for getting a variant from a variant array or scalar.
VariantPretty
Returns a pretty-printed JSON string from a VariantArray
VariantSchema
Logical schema builder for variant typed_value trees.
VariantToJsonUdf
Returns a JSON string from a VariantArray

Functions

boolean_buffer_and_then
Combines this BooleanBuffer with another using logical AND on the selected bits.
extract_execution_metrics
Extracts execution metrics from a physical execution plan.