This module contains the cache implementation for the Parquet reader.
Structs
- BatchID
- BatchID is a unique identifier for a batch of rows, it is row id divided by the batch size.
- Cached
Column - A column in the cache.
- Cached
File - A file in the cache.
- Cached
RowGroup - A row group in the cache.
- Liquid
Cache Parquet - The main cache structure.
- Parquet
ArrayID - This is a unique identifier for a row in a parquet file.
Type Aliases
- Cached
Column Ref - A reference to a cached column.
- Liquid
Cache Parquet Ref - A reference to the main cache structure.