Module optimizers

Module optimizers 

Optimizers for the Parquet module

Structs

LineageOptimizer
Logical optimizer that analyses the logical plan to detect columns that are only used via compatible EXTRACT or variant_get projections.
LocalModeOptimizer
Physical optimizer rule for local mode liquid cache

Functions

rewrite_data_source_plan
Rewrite the data source plan to use liquid cache.