pub fn rewrite_data_source_plan(
plan: Arc<dyn ExecutionPlan>,
cache: &LiquidCacheParquetRef,
eager_shredding: bool,
) -> Arc<dyn ExecutionPlan>Expand description
Rewrite the data source plan to use liquid cache.
pub fn rewrite_data_source_plan(
plan: Arc<dyn ExecutionPlan>,
cache: &LiquidCacheParquetRef,
eager_shredding: bool,
) -> Arc<dyn ExecutionPlan>Rewrite the data source plan to use liquid cache.