pub struct FilterCandidateBuilder { /* private fields */ }Expand description
Helper to build a FilterCandidate.
This will do several things
- Determine the columns required to evaluate the expression
- Calculate data required to estimate the cost of evaluating the filter
Implementations
Sourceimpl FilterCandidateBuilder
impl FilterCandidateBuilder
Sourcepub fn new(expr: Arc<dyn PhysicalExpr>, file_schema: SchemaRef) -> Self
pub fn new(expr: Arc<dyn PhysicalExpr>, file_schema: SchemaRef) -> Self
Create a new FilterCandidateBuilder
Sourcepub fn build(
self,
metadata: &ParquetMetaData,
) -> Result<Option<FilterCandidate>>
pub fn build( self, metadata: &ParquetMetaData, ) -> Result<Option<FilterCandidate>>
Attempt to build a FilterCandidate from the expression
Return values
Ok(Some(candidate))if the expression can be used as an ArrowFilterOk(None)if the expression cannot be used as an ArrowFilterErr(e)if an error occurs while building the candidate