Optimizers for the Parquet module
Structs
- Lineage
Optimizer - Logical optimizer that analyses the logical plan to detect columns that
are only used via compatible
EXTRACTorvariant_getprojections. - Local
Mode Optimizer - Physical optimizer rule for local mode liquid cache
Functions
- rewrite_
data_ source_ plan - Rewrite the data source plan to use liquid cache.